@@ -1,8 +1,15 @@
+# Copyright (c) 2014, Facebook, Inc.  All rights reserved.
+#
+# This source code is licensed under the BSD-style license found in the
+# LICENSE file in the root directory of this source tree. An additional grant
+# of patent rights can be found in the PATENTS file in the same directory.
+#
+"""Module providing tasks that help with dbus integration"""
 from __future__ import absolute_import
 
 from ..vtask import VTask, SkipTask
 from ..sparts import option
-from ..fb303.dbus import FacebookDbusService
+from ..fb303.dbus import FB303DbusService
 from .fb303 import FB303ProcessorTask
 
 from dbus.mainloop.glib import DBusGMainLoop
@@ -14,6 +21,7 @@ import time
 
 
 class VServiceDBusObject(dbus.service.Object):
+    """DBus interface implementation that exports common VService methods"""
     def __init__(self, dbus_service):
         self.dbus_service = dbus_service
         self.service = self.dbus_service.service
@@ -71,6 +79,7 @@ class VServiceDBusObject(dbus.service.Object):
 
 
 class DBusMainLoopTask(VTask):
+    """Configure and run the DBus Main Loop in a sparts task"""
     THREADS_INITED = False
     mainloop = None
 
@@ -108,7 +117,9 @@ class DBusMainLoopTask(VTask):
         self.mainloop = None
 
 class DBusTask(VTask):
+    """Base Class for Tasks that depend on the DBus Main Loop"""
     DEPS = [DBusMainLoopTask]
+    LOOPLESS = True
 
     def initTask(self):
         super(DBusTask, self).initTask()
@@ -120,9 +131,9 @@ class DBusTask(VTask):
 
 
 class DBusServiceTask(DBusTask):
+    """Glue Task for exporting this VService over dbus"""
     OPT_PREFIX = 'dbus'
     BUS_NAME = None
-    LOOPLESS = True
     BUS_CLASS = VServiceDBusObject
 
     bus_name = option(default=lambda cls: cls.BUS_NAME, metavar='NAME',
@@ -151,7 +162,7 @@ class DBusServiceTask(DBusTask):
         self.sparts_dbus = self.BUS_CLASS(self)
         task = self.service.getTask(FB303ProcessorTask)
         if task is not None:
-            self.fb303_dbus = FacebookDbusService(
+            self.fb303_dbus = FB303DbusService(
                 self.dbus_service, task.processor, self.service.name)
 
     def stop(self):
