@@ -1,9 +1,21 @@
-from ..vtask import VTask, ExecuteContext, TryLater
-from ..sparts import option
-from Queue import Queue, Empty
+# Copyright (c) 2014, Facebook, Inc.  All rights reserved.
+#
+# This source code is licensed under the BSD-style license found in the
+# LICENSE file in the root directory of this source tree. An additional grant
+# of patent rights can be found in the PATENTS file in the same directory.
+#
+"""Module for tasks related to doing work from a queue"""
+from six.moves import queue
+from sparts.sparts import option
+from sparts.vtask import VTask, ExecuteContext, TryLater
 
 class QueueTask(VTask):
+    """Task that calls `execute` for all work put on its `queue`"""
+    MAX_ITEMS = 0
     WORKERS = 1
+    max_items = option(type=int, default=lambda cls: cls.MAX_ITEMS,
+                       help='Set a bounded queue length.  This may '
+                            'cause unexpected deadlocks. [%(default)s]')
     workers = option(type=int, default=lambda cls: cls.WORKERS,
                      help='Number of threads to spawn to work on items from '
                           'its queue. [%(default)s]')
@@ -14,7 +26,7 @@ class QueueTask(VTask):
 
     def initTask(self):
         super(QueueTask, self).initTask()
-        self.queue = Queue()
+        self.queue = queue.Queue(maxsize=self.max_items)
         self._shutdown_sentinel = object()
 
     def stop(self):
@@ -28,7 +40,7 @@ class QueueTask(VTask):
                 if item is self._shutdown_sentinel:
                     self.queue.put(item)
                     break
-            except Empty:
+            except queue.Empty:
                 continue
 
             if isinstance(item, ExecuteContext):
@@ -58,5 +70,3 @@ class QueueTask(VTask):
     def unhandledErrback(self, error):
         self.unhandled = error
         return None
-
-
