@@ -1,3 +1,10 @@
+# Copyright (c) 2014, Facebook, Inc.  All rights reserved.
+#
+# This source code is licensed under the BSD-style license found in the
+# LICENSE file in the root directory of this source tree. An additional grant
+# of patent rights can be found in the PATENTS file in the same directory.
+#
+"""Module containing helpers for implementing fb303 with `VService`s"""
 from .fb303 import FacebookService
 from .fb303.ttypes import fb_status
 
@@ -18,21 +25,32 @@ class VServiceFB303Processor(FacebookService.Processor):
         if self.service._stop:
             return fb_status.STOPPING
         for task in self.service.tasks:
+            # Only check LOOPLESS tasks for "dead" threads
             if not task.LOOPLESS:
                 for thread in task.threads:
                     if not thread.isAlive():
                         return fb_status.WARNING
+
+        # Return WARNING if there are any registered warnings
+        if self.service.getWarnings():
+            return fb_status.WARNING
         return fb_status.ALIVE
 
     def getStatusDetails(self):
+        messages = []
         if self.service._stop:
-            return '%s is shutting down' % (self.getName())
+            messages.append('%s is shutting down' % (self.getName()))
+
+        # Check for dead threads
         for task in self.service.tasks:
             if not task.LOOPLESS:
                 for thread in task.threads:
                     if not thread.isAlive():
-                        return '%s has dead threads!' % task.name
-        return ''
+                        messages.append('%s has dead threads!' % task.name)
+
+        # Append any registered warnings
+        messages.extend(self.service.getWarnings().values())
+        return '\n'.join(messages)
 
     def getCounters(self):
         result = {}
